<?php

namespace Drupal\year\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Field\WidgetInterface;

/**
 * Plugin implementation of the 'year_default' widget.
 *
 * @FieldWidget(
 *   id = "year_default",
 *   label = @Translation("Enter Year"),
 *   field_types = {
 *     "year"
 *   }
 * )
 */
class YearDefaultWidget extends WidgetBase implements WidgetInterface {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $field_settings = $this->getFieldSettings();

    $element['#description'] = $this->t('Enter a year from @min to @max.', [
      '@min' => $field_settings['min'],
      '@max' => $field_settings['max'],
    ]);

    $element['value'] = $element + [
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->value) ? $items[$delta]->value : '',
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected function getFieldSettings() {
    $settings = $this->fieldDefinition->getSettings();

    $max = $settings['max'];
    if (!is_numeric($max)) {
      $settings['max'] = date('Y', strtotime($max));
    }

    return $settings;
  }

}
